==> web-fw2_2_2.zip: web-fw2_2_2/j2src/test/test/org/itscool/commons/TestAngoutAndHexPropertyFile.java <==
package test.org.itscool.commons;

import java.io.IOException;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.itscool.commons.file.HexPropertyFile;
import org.itscool.commons.util.AngouUtil;

public class TestAngoutAndHexPropertyFile extends TestCase{
    private String path =  "pwd2.txt";
    
    public TestAngoutAndHexPropertyFile(String name){
        super(name);
    }
    /**
     * Íf[^Hex`Ńt@CɏރeXg
     */
    public void testAddAngou(){
        String user = "kano";
        String pwd =  "kano";
        
        boolean append = false;
        
        try{
            //[UŃpX[h(pwd)Í
            byte[] pwdAngou = AngouUtil.encrypt(user, pwd);
            //[UƈÍpX[ho^
            HexPropertyFile pFile = new HexPropertyFile(path);
            pFile.removeAll();
            if( !pFile.writeHex(user, pwdAngou, append) ){
                fail("̃[U͊ɓo^Ă܂ [" + user + "] pwd [" + pwd + "]" );
            }
        }catch( IOException ioe ){
            fail(ioe.getMessage());
        }
        
    }
    
    /**
     * t@CHex`ŏ܂ĂÍǂݍ
     * Í𕜌eXg
     */
    public void testRead(){
        String user = "kano";
        boolean append = false;
        
        HexPropertyFile pFile = null;
        try{
        	pFile = new HexPropertyFile(path);
        }catch( IOException ioe ){
			fail(ioe.getMessage());
        }
        //[UÍpX[h擾
        byte[] chkPwd = pFile.readHex(user);
        //ÍpX[h
        String chkPwdStr = new String();
        try{
            chkPwdStr = AngouUtil.decrypt(user, chkPwd );
        }catch( IOException ioe ){
            fail(ioe.getMessage());
        }
        
    }
    
    /**
     * f[^폜eXg
    */
    public void testDell(){
        String user = "kano";
        //String pwd =  "kano";
        //boolean append = false;
        
        HexPropertyFile pFile = null;
		try{
			pFile = new HexPropertyFile(path);
		}catch( IOException ioe ){
			fail(ioe.getMessage());
		}
		/*
        try{
            //[UŃpX[h(pwd)Í
            byte[] pwdAngou = Angou.encrypt(user, pwd);
            if( !pFile.writeHex(user, pwdAngou, append) ){
                fail("̃[U͊ɓo^Ă܂ [" + user + "] pwd [" + pwd + "]" );
            }
        }catch(IOException ioe){
            fail("writeHex()ŃG[܂F" + ioe.getMessage());
        }
        */
        try{
            if( !pFile.delete(user) ){
                fail("[U̍폜Ɏs܂");
            }
        }catch(IOException ioe){
            fail("delete()ŃG[܂F" + ioe.getMessage());
        }
    }
	public static Test suite() {
		return new TestSuite(TestAngoutAndHexPropertyFile.class);
	}
}

==> web-fw3_0_2.zip: web-fw3_0_2/j2src/test/test/org/itscool/commons/TestAngoutAndHexPropertyFile.java <==
package test.org.itscool.commons;

import java.io.IOException;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

import org.itscool.commons.property.HexPropertyFile;
import org.itscool.commons.util.AngouUtil;

public class TestAngoutAndHexPropertyFile extends TestCase{
    private String path =  "pwd2.txt";
    
    public TestAngoutAndHexPropertyFile(String name){
        super(name);
    }
    /**
     * Íf[^Hex`Ńt@CɏރeXg
     */
    public void testAddAngou(){
        String user = "kano";
        String pwd =  "kano";
        
        boolean append = false;
        
        try{
            //[UŃpX[h(pwd)Í
            byte[] pwdAngou = AngouUtil.encrypt(user, pwd);
            //[UƈÍpX[ho^
            HexPropertyFile pFile = new HexPropertyFile(path);
            pFile.removeAll();
            if( !pFile.writeHex(user, pwdAngou, append) ){
                fail("̃[U͊ɓo^Ă܂ [" + user + "] pwd [" + pwd + "]" );
            }
        }catch( IOException ioe ){
            fail(ioe.getMessage());
        }
        
    }
    
    /**
     * t@CHex`ŏ܂ĂÍǂݍ
     * Í𕜌eXg
     */
    public void testRead(){
        String user = "kano";
        boolean append = false;
        
        HexPropertyFile pFile = null;
        try{
        	pFile = new HexPropertyFile(path);
        }catch( IOException ioe ){
			fail(ioe.getMessage());
        }
        //[UÍpX[h擾
        byte[] chkPwd = pFile.readHex(user);
        //ÍpX[h
        try{
            String chkPwdStr = AngouUtil.decrypt(user, chkPwd );
        }catch( IOException ioe ){
            fail(ioe.getMessage());
        }
        
    }
    
    /**
     * f[^폜eXg
    */
    public void testDell(){
        String user = "kano";
        //String pwd =  "kano";
        //boolean append = false;
        
        HexPropertyFile pFile = null;
		try{
			pFile = new HexPropertyFile(path);
		}catch( IOException ioe ){
			fail(ioe.getMessage());
		}
		/*
        try{
            //[UŃpX[h(pwd)Í
            byte[] pwdAngou = Angou.encrypt(user, pwd);
            if( !pFile.writeHex(user, pwdAngou, append) ){
                fail("̃[U͊ɓo^Ă܂ [" + user + "] pwd [" + pwd + "]" );
            }
        }catch(IOException ioe){
            fail("writeHex()ŃG[܂F" + ioe.getMessage());
        }
        */
        try{
            if( !pFile.delete(user) ){
                fail("[U̍폜Ɏs܂");
            }
        }catch(IOException ioe){
            fail("delete()ŃG[܂F" + ioe.getMessage());
        }
    }
	public static Test suite() {
		return new TestSuite(TestAngoutAndHexPropertyFile.class);
	}
}
